@@ -1,8 +1,9 @@
+#!/usr/bin/perl -W
 use lib qw(./lib);
 use CGI;
 use CGI::Carp qw(fatalsToBrowser);
 use HTML::Menu::TreeView qw(Tree jscript setStyle setDocumentRoot setSize setClasic);
-# use 5.008006;
+use 5.008006;
 use Getopt::Long;
 my $htdocs = "/srv/www/htdocs";
 my $cgi           = new CGI;
@@ -30,11 +31,6 @@ my @t             = (
 	target => '_parent',
 	image => 'deb.png'
 	},
-{
-	text   => 'Treeview Homepage',
-	href   => 'http://treeview.lindnerei.de/',
-	target => '_parent',
-},
 );
 setDocumentRoot($htdocs);
 setStyle($style);
@@ -45,7 +41,7 @@ print OUT "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"ht
 <html>
 <head>
 <title>Navigation</title>
-<link rel=\"stylesheet\" type=\"text/css\" href=\"/style/$style/$size/html-menu-treeview/$style.css\">
+<link rel=\"stylesheet\" type=\"text/css\" href=\"/style/$style/16/html-menu-treeview/$style.css\">
 <script language=\"JavaScript\" type=\"text/javascript\">
 //<!--
 " . jscript() . '
@@ -53,18 +49,19 @@ print OUT "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"ht
 </script>
 </head>
 <body>
-<table align="center" class="mainborder" cellpadding="0"  cellspacing="0" summary="mainLayout" width="100%" ><tr><td align="center" >' . Tree(\@t).'</select><br><p></td></tr></table></body></html>';
+<table align=\"center\" class=\"mainborder\" cellpadding=\"0\"  cellspacing=\"0\" summary=\"mainLayout\" width=\"100%\" ><tr><td align=\"center" >' . Tree(\@t).'</select><br><p></td></tr></table></body></html>';
 close(OUT);
 open FRAME , ">$htdocs/TreeView.html" or die "$!";
 print FRAME  '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">
 <html>
 <head>
-<title>Html::Menu::TreeView</title>
+<title>Treeview.pm</title>
+<meta name="AUTHOR" content="Dirk Lindner">
 <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
 <meta name="robots" content="index">
-<meta name="keywords" lang="de" content="Html::Menu::TreeView Treeview Treeview.pm Treeview.html">
+<meta name="keywords" lang="de" content="Treeview Treeview.pm Treeview.html">
 </head>
-<frameset cols="300,*">
+<frameset cols="260,*">
 <frame src="/Treenavi.html" name="navi">
 <frame src="/html-menu-treeview.html" name="rightFrame">
 </frameset>
